iproute: rename 'get_jiffies' since it uses msecs

The get_jiffies() function retrieves rtt-type values in units of
milliseconds. This patch updates the function name accordingly,
following the pattern given by dst_metric() <=> dst_metric_rtt().
diff --git a/include/utils.h b/include/utils.h
index 77c8e5a..47f8e07 100644
--- a/include/utils.h
+++ b/include/utils.h
@@ -79,7 +79,7 @@
 
 extern int get_integer(int *val, const char *arg, int base);
 extern int get_unsigned(unsigned *val, const char *arg, int base);
-extern int get_jiffies(unsigned *val, const char *arg, int *raw);
+extern int get_time_rtt(unsigned *val, const char *arg, int *raw);
 #define get_byte get_u8
 #define get_ushort get_u16
 #define get_short get_s16
diff --git a/ip/iproute.c b/ip/iproute.c
index d48e743..06d2507 100644
--- a/ip/iproute.c
+++ b/ip/iproute.c
@@ -835,7 +835,7 @@
 				mxlock |= (1<<RTAX_RTT);
 				NEXT_ARG();
 			}
-			if (get_jiffies(&rtt, *argv, &raw))
+			if (get_time_rtt(&rtt, *argv, &raw))
 				invarg("\"rtt\" value is invalid\n", *argv);
 			rta_addattr32(mxrta, sizeof(mxbuf), RTAX_RTT, 
 				(raw) ? rtt : rtt * 8);
@@ -843,7 +843,7 @@
 			unsigned rto_min;
 			NEXT_ARG();
 			mxlock |= (1<<RTAX_RTO_MIN);
-			if (get_jiffies(&rto_min, *argv, &raw))
+			if (get_time_rtt(&rto_min, *argv, &raw))
 				invarg("\"rto_min\" value is invalid\n",
 				       *argv);
 			rta_addattr32(mxrta, sizeof(mxbuf), RTAX_RTO_MIN,
@@ -895,7 +895,7 @@
 				mxlock |= (1<<RTAX_RTTVAR);
 				NEXT_ARG();
 			}
-			if (get_jiffies(&win, *argv, &raw))
+			if (get_time_rtt(&win, *argv, &raw))
 				invarg("\"rttvar\" value is invalid\n", *argv);
 			rta_addattr32(mxrta, sizeof(mxbuf), RTAX_RTTVAR,
 				(raw) ? win : win * 4);
diff --git a/lib/utils.c b/lib/utils.c
index 95adc0c..1b42222 100644
--- a/lib/utils.c
+++ b/lib/utils.c
@@ -93,14 +93,13 @@
 }
 
 /*
  * get_jiffies is "translated" from a similar routine "get_time" in
  * tc_util.c.  we don't use the exact same routine because tc passes
  * microseconds to the kernel and the callers of get_jiffies want 
  * to pass jiffies, and have a different assumption for the units of
  * a "raw" number.
  */
-
-int get_jiffies(unsigned *jiffies, const char *arg, int *raw)
+int get_time_rtt(unsigned *val, const char *arg, int *raw)
 {
 	double t;
 	unsigned long res;
@@ -135,9 +134,9 @@
 
 	/* emulate ceil() without having to bring-in -lm and always be >= 1 */
 
-	*jiffies = t;
-	if (*jiffies < t)
-		*jiffies += 1;
+	*val = t;
+	if (*val < t)
+		*val += 1;
 	
         return 0;
@@ -93,14 +93,13 @@
 
 /*
- * get_jiffies is "translated" from a similar routine "get_time" in
- * tc_util.c.  we don't use the exact same routine because tc passes
- * microseconds to the kernel and the callers of get_jiffies want 
- * to pass jiffies, and have a different assumption for the units of
- * a "raw" number.
+ * get_time_rtt is "translated" from a similar routine "get_time" in
+ * tc_util.c.  We don't use the exact same routine because tc passes
+ * microseconds to the kernel and the callers of get_time_rtt want to
+ * pass milliseconds (standard unit for rtt values since 2.6.27), and
+ * have a different assumption for the units of a "raw" number.
  */